@@ -1,4 +1,3 @@
-from types import NoneType
 from sentinels import NOTHING
 from .exceptions import InvalidPath
 from .exceptions import CannotDeduceType
@@ -14,9 +13,10 @@ def assign_path(conf, path, value):
 def assign_path_expression(conf, expr, deduce_type=False):
     path, value = expr.split("=", 1)
     if deduce_type:
-        leaf_type = type(get_path(conf, path))
-        if leaf_type is NoneType:
+        leaf = get_path(conf, path)
+        if leaf is None:
             raise CannotDeduceType("Cannot deduce type of path {0!r}".format(path))
+        leaf_type = type(leaf)
     else:
         leaf_type = str
     assign_path(conf, path, leaf_type(value))
